<?php
// File: $Id: pssession.php,v 1.1 2003/11/26 15:03:25 hdonner Exp $
// ----------------------------------------------------------------------
// PHP Snippets
// Copyright 2001-2004 by Hinrich Donner
// http://sourceforge.net/projects/psnippets/
// ----------------------------------------------------------------------
// LICENSE
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License (GPL)
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// To read the license please visit http://www.gnu.org/copyleft/gpl.html
// ----------------------------------------------------------------------

/**
 * pssession.php
 *
 * This file contains the class psSession.
 *
 * @version 0.1.1
 * @since 0.1.1
 * @copyright Hinrich Donner (c) 2002-2004
 * @package PHP Snippets
 * @subpackage System
 * @category Data Storage
 */

/**
 * PS_SESSION_NAME
 *
 * The name of the session.
 */
define('PS_SESSION_NAME',               'psid');

/**
 * _PS_SESSION_PREFIX
 *
 * This prefix is used on session variables.  It is to make sure that
 * there is no possibility for problems with other global variables.
 * There should not be any reason why to change it.
 *
 * @access private
 */
define('_PS_SESSION_PREFIX',            '__PSV_');

/**
 * __PS_SESSION_INSTANCE
 *
 * The name of the global instance of the session class.
 *
 * @access private
 */
define('__PS_SESSION_INSTANCE',         '__ps_session_instance');

/**
 * __PS_INIT
 *
 * The name of the global variable to indicate if the session were
 * started.
 *
 * @access private
 */
define('__PS_INIT',                     '__ps_init');
$GLOBALS[__PS_INIT] = false;

/**
 * Class psSession
 *
 * This class handles the access to session vars.  If session is not
 * started it will started by the constructor.
 */
class psSession
{
    /**
     * @var bool This is true, if register_globals is true
     */
    var $global_scope;

    /**
     * @var bool True if the globale array HTTP_SESSION_VARS exist
     */
    var $http_scope;

    /**
     * @var array A reference on $HTTP_SESSION_VARS
     */
    var $http;

    /**
     * psSession
     *
     * The constructor.
     *
     * @access public
     * @see psSession::GetInstance()
     */
    function psSession()
    {
        // Get some informations
        //
        $this->global_scope = ini_get('register_globals');

        // Test on HTTP_SESSION_VARS
        //
        if (array_key_exists('HTTP_SESSION_VARS', $GLOBALS))
        {
            $this->http_scope = true;
            $this->http =& $GLOBALS['HTTP_SESSION_VARS'];
        }

        // Init the session
        //
        $this->Init();
    }

    /**
     * Init
     *
     * Initialize the sessions.  This method has only to be called once
     * in a script.
     */
    function Init()
    {
        // Test if we have to kick the session.
        //
        if ($GLOBALS[__PS_INIT])
            return;

        // Set the name
        //
        session_name(PS_SESSION_NAME);

        // Start session if not done now
        //
        if (!isset($_SESSION) || !is_array($_SESSION))
            session_start();

        // Remember
        //
        $GLOBALS[__PS_INIT] = true;
    }

    /**
     * GetInstance
     *
     * Get the single Instance of the session class.  If you are using
     * this method, you MUST not have any instance before.  Use it like
     * <code>
     * $session = psSession::GetInstance();
     * $session->Get('my_var');
     * </code>
     *
     * @return reference
     * @see psSession::psSession();
     */
    function &GetInstance()
    {
        if (!array_key_exists(__PS_SESSION_INSTANCE, $GLOBALS))
        {
            $GLOBALS[__PS_SESSION_INSTANCE] =& new psSession();
            $GLOBALS[__PS_SESSION_INSTANCE]->Init();
        }
        return $GLOBALS[__PS_SESSION_INSTANCE];
    }

    /**
     * Exists
     *
     * Tests if a session var is present
     *
     * @param string $name The nam of the session var
     * @return bool
     * @see psSession::Get(), psSession::GetReference()
     */
    function Exists($name)
    {
        if (empty($name))
            return false;

        return (array_key_exists(_PS_SESSION_PREFIX.$name, $_SESSION));
    }

    /**
     * Get
     *
     * Return a copy of a session var
     *
     * @param string $name The nam of the session var
     * @return mixed The session var if any or NULL
     * @see psSession::Exists(), psSession::GetReference()
     */
    function Get($name)
    {
        if ($this->Exists($name))
            return $_SESSION[_PS_SESSION_PREFIX.$name];
        else
            return NULL;
    }

    /**
     * Set
     *
     * Set a session var
     *
     * @param string $name The nam of the session var
     * @param mixed $value The var
     * @return bool
     */
    function Set($name, $value)
    {
        if (empty($name))
            return false;

        $_SESSION[_PS_SESSION_PREFIX.$name] = $value;
        if ($this->global_scope) {
            $GLOBALS[_PS_SESSION_PREFIX.$name] = $value;
            session_register(_PS_SESSION_PREFIX.$name);
        }
        if ($this->http_scope)
            $this->http[_PS_SESSION_PREFIX.$name] = $value;
        return true;
    }

    /**
     * Delete
     *
     * Removes a var from the session. Take also care on the global
     * scope.
     *
     * @param string $name The name of the var
     */
    function Delete($name)
    {
        if (empty($name))
            return false;

        if ($this->global_scope) {
            unset($GLOBALS[_PS_SESSION_PREFIX.$name]);
            session_unregister(_PS_SESSION_PREFIX.$name);
        }

        if ($this->http_scope)
            unset($this->http[_PS_SESSION_PREFIX.$name]);

        unset($_SESSION[_PS_SESSION_PREFIX.$name]);

        return true;
    }

    /**
     * Get Reference
     *
     * Returns the reference to a session var
     *
     * @param string $name The name of the session var
     * @return reference to the session var
     * @see psSession::Get()
     */
    function &GetReference($name)
    {
        if ($this->Exists($name))
            return $_SESSION[_PS_SESSION_PREFIX.$name];
    }
}

// $Log: pssession.php,v $
// Revision 1.1  2003/11/26 15:03:25  hdonner
// - Klasse psSession
//
// Revision 1.1  2003/11/05 12:50:39  hdonner
// - psSession handles PHP sessions
//
//
?>
