<?php
// ----------------------------------------------------------------------
// File: $Id: vkparray.php,v 1.2.2.1 2004/01/17 22:36:53 hdonner Exp $
// ----------------------------------------------------------------------
// PHP-Nuke-VKP
// Copyright 2001-2004 by PHP-Nuke-VKP-Team
// http://developer.berlios.de/projects/phpnukevkp/
// ----------------------------------------------------------------------
// LICENSE
//
// Dieses Programm ist freie Software; Sie knnen sie beliebig verteilen
// und/oder nderungen vornehmen, solange Sie dieses unter den
// Lizenzbedingungen der Version 2 oder hher der GNU General Public
// License (GPL), verffentlicht von der Free Software Foundation tun.
//
// Dieses Programm wurde in der Hoffnung erstellt, dass es fr Sie
// ntzlich sein knnte. Es wird jedoch ohne jeden Anspruch auf
// Gewhrleistung verffentlicht. Sie knnen auch nicht davon ausgehen,
// dass das Programm Dinge verrichtet, wie es erwartet wird.
//
// Lesen Sie die Lizenzbedinguneg unter der URL
// http://www.gnu.org/copyleft/gpl.html fr weitere Details.
// ----------------------------------------------------------------------

/**
 * vkparray.php
 *
 * Diese Datei enthlt Klassen und Funktionen zur Handhabung
 * von Arrays.
 *
 * @author Hinrich Donner
 * @version 5.5.1
 * @since 0.1
 * @package PHP-Nuke-VKP
 * @subpackage System
 * @category System
 * @link http://developer.berlios.de/projects/phpnukevkp/
 */

/**
 * vkpArray
 *
 * Diese Klasse handhabt ein Array.  Im wesentlichen dient diese Klasse als
 * Basis.
 *
 * @author Hinrich Donner
 * @version 0.1
 * @since 5.5.1
 * @see vkpAssocArray
 */
class vkpArray
{
    /**
     * items
     *
     * Die Elemente.  Im Normalfall empfiehlt sich der Zugriff ber die
     * Methoden, um die Datenintegritt sicherzustellen.
     *
     * @var array
     */
    var $items;

    /**
     * vkpArray
     *
     * Konstruktor
     *
     * @access protected
     * @author Hinrich Donner
     * @version
     * @since
     */
    function vkpArray($source = null)
    {
        $this->Init(&$source);
    }

    /**
     * Init
     *
     * Initialisiert das Array.
     *
     * @param mixed $source Basisdaten oder null
     * @author Hinrich Donner
     * @since 5.5.1
     * @version 0.1
     */
    function Init($source = null)
    {
        if (empty($source))
            $this->items = array();
        elseif (is_array($source))
            $this->items = $source;
        elseif (is_a($source, 'vkpArray'))
            $this->items = $source->items;
        else
            $this->items = array($source);
    }

    /**
     * Free
     *
     * Gibt alle Daten frei.
     *
     * @author Hinrich Donner
     * @since 5.5.1
     * @version 0.1
     */
    function Free()
    {
        unset($this->items);
    }

    /**
     * Clear
     *
     * Lscht alte Daten und initialisiert ein leeres Array.
     *
     * @author Hinrich Donner
     * @since 5.5.1
     * @version 0.1
     */
    function Clear()
    {
        $this->Free();
        $this->Init();
    }

    /**
     * Count
     *
     * Liefert die Anzahl der vorhandenen Elemente zurck.
     *
     * @return int
     * @author Hinrich Donner
     * @since 5.5.1
     * @version 0.1
     */
    function Count()
    {
        return count($this->items);
    }

    /**
     * GetAll
     *
     * Liefert alle Elemente zurck.
     *
     * @return array
     * @author Hinrich Donner
     * @since 5.5.1
     * @version 0.1
     * @see vkpArray::GetAllAsReference()
     */
    function GetAll()
    {
        return $this->items;
    }

    /**
     * GetAllAsReference
     *
     * Liefert alle Elemente zurck.
     *
     * @return array
     * @author Hinrich Donner
     * @since 5.5.1
     * @version 0.1
     * @see vkpArray::GetAll()
     */
    function &GetAllAsReference()
    {
        return $this->items;
    }

    /**
     * Add
     *
     * Fgt ein Element hinzu.
     *
     * @param mixed $item Das Element
     * @author Hinrich Donner
     * @since 5.5.1
     * @version 0.1
     */
    function Add($item)
    {
        $this->items[] = $item;
    }
} // Class

/**
 * vkpAssocArray
 *
 * @author Hinrich Donner
 * @version
 * @since
 */
class vkpAssocArray extends vkpArray
{
    /**
     * vkpAssocArray
     *
     * Konstruktor
     *
     * @author Hinrich Donner
     * @version 5.5.1
     * @since 0.1
     */
    function vkpAssocArray()
    {
        $this->vkpArray();
    }

    /**
     * Exists
     *
     * Prft, ob ein Element existiert.
     *
     * @param string $name Der Name des Elementes
     * @return bool TRUE oder FALSE
     * @author Hinrich Donner
     * @since 5.5.1
     * @version 0.1
     * @see vkpAssocArray::Get()
     */
    function Exists($name)
    {
        if (!empty($name) && array_key_exists($name, $this->items))
            return true;
        return false;
    }

    /**
     * Get
     *
     * Liefert ein Element aus dem Array zurck.
     *
     * @param string $name Name des Elements
     * @param mixed $default Ein Vorgabewert
     * @return mixed Der Wert oder die Vorgabe
     * @author Hinrich Donner
     * @since 5.5.1
     * @version 0.1
     * @see vkpAssocArray::Exists()
     */
    function Get($name, $default = null)
    {
        if ($this->Exists($name))
            return $this->items[$name];
        return $default;
    }

} // Class

// $Log: vkparray.php,v $
// Revision 1.2.2.1  2004/01/17 22:36:53  hdonner
// - vkpAssocArray::Get()
//
// Revision 1.2  2004/01/06 14:43:09  hdonner
// - vkpAssocArray
//
// Revision 1.1  2004/01/02 17:12:50  hdonner
// - OOP-API Themes
//
// Revision 1.1  2003/12/31 17:02:09  hdonner
// - Init
//
//
?>
