<?php
// ----------------------------------------------------------------------
// File: $Id: vkplanguages.php,v 1.1 2004/01/02 20:39:37 hdonner Exp $
// ----------------------------------------------------------------------
// PHP-Nuke-VKP
// Copyright 2001-2004 by PHP-Nuke-VKP-Team
// http://developer.berlios.de/projects/phpnukevkp/
// ----------------------------------------------------------------------
// LICENSE
//
// Dieses Programm ist freie Software; Sie knnen sie beliebig verteilen
// und/oder nderungen vornehmen, solange Sie dieses unter den
// Lizenzbedingungen der Version 2 oder hher der GNU General Public
// License (GPL), verffentlicht von der Free Software Foundation tun.
//
// Dieses Programm wurde in der Hoffnung erstellt, dass es fr Sie
// ntzlich sein knnte. Es wird jedoch ohne jeden Anspruch auf
// Gewhrleistung verffentlicht. Sie knnen auch nicht davon ausgehen,
// dass das Programm Dinge verrichtet, wie es erwartet wird.
//
// Lesen Sie die Lizenzbedinguneg unter der URL
// http://www.gnu.org/copyleft/gpl.html fr weitere Details.
// ----------------------------------------------------------------------

/**
 * vkplanguage.php
 *
 * Diese Datei enthlt Klassen und Funktionen zur Handhabnung von
 * Sprachen.
 * 
 * @author Hinrich Donner
 * @version 5.5.1
 * @since 0.1
 * @package PHP-Nuke-VKP
 * @subpackage System
 * @category Sprachen
 * @link http://developer.berlios.de/projects/phpnukevkp/
 */

/**
 * Bentigte Klassen
 *
 * @ignore
 */
require_once VKP_INCLUDE_DIR . '/classes/vkparray.php';
require_once VKP_INCLUDE_DIR . '/classes/vkpfile.php';

/**
 * __VKP_LANGUAGE_INSTANCE
 * 
 * Der Name der globalen Variablen, die die Instanz enthlt.
 * 
 * @access private
 * @see vkpThemes
 */
define('__VKP_LANGUAGE_INSTANCE', '__vkp_language_instance');

/**
 * VKP_LANGUAGE_DIR
 * 
 * Das Verzeichnis der Sprachdateien. Hierbei darf es sich niemals
 * um einen absoluten Pfad handeln, da gleichnamige Verzeichnisse 
 * als Unterverzeichnisse in admin/ und modules/MyModul/ erwartet
 * werden.
 *
 * @see vkpLanguages
 */
define('VKP_LANGUAGE_DIR', 'language');

/** 
 * vkpLanguage
 *
 * Diese Klasse enthlt Methoden und Eigenschaften fr die Mehrsprachigkeit.
 * 
 * @author Hinrich Donner
 * @version 0.1
 * @since 5.5.1
 */
class vkpLanguages extends vkpArray
{
    /**
     * current
     * 
     * Der Name der aktuellen Sprache.
     * 
     * @var string
     */
    var $current;
    
    /**
     * default
     * 
     * Der Name der Vorgabesprache.
     * 
     * @var string
     * @see vkpConfig
     */
    var $default;
    
    /**
     * vkpLanguage
     *
     * Der Konstruktor
     *
     * @author Hinrich Donner
     * @since 5.5.1
     * @version 0.1
     * @access protected
     */
    function vkpLanguages()
    {
    	$this->vkpArray();
        $config =& vkpConfig::GetInstance();
        $this->default = $config->language;
        $this->current = $this->default;
    }
    
    /**
     * GetInstance
     *
     * Liefert die Instanz.
     *
     * @return vkpLanguages
     * @author Hinrich Donner
     * @since 5.5.1
     * @version 0.1
     */
    function &GetInstance()
    {
    	if (!array_key_exists(__VKP_LANGUAGE_INSTANCE, $GLOBALS)
                || !is_a($GLOBALS[__VKP_LANGUAGE_INSTANCE], 'vkpLanguages'))
            $GLOBALS[__VKP_LANGUAGE_INSTANCE] =& new vkpLanguages();
        return $GLOBALS[__VKP_LANGUAGE_INSTANCE];
    }
    
    /**
     * _MakeFilenames
     *
     * Erzeugt die Dateinamen fr die Sprachdateisuche.
     *
     * @param string $mask Die Suchmaske
     * @return array Die Liste der Dateinamen
     * @author Hinrich Donner
     * @since 5.5.1
     * @version 0.1
     * @access protected
     */
    function _MakeFilenames($mask)
    {
        if ($this->current == $this->default)
            $result = array(sprintf($mask, 'lang-' . vkpVarPrepForOs($this->current) . '.php'),
                            sprintf($mask, 'lang-english.php'));
        else
            $result = array(sprintf($mask, 'lang-' . vkpVarPrepForOs($this->current) . '.php'),
                            sprintf($mask, 'lang-' . vkpVarPrepForOs($this->default) . '.php'),
                            sprintf($mask, 'lang-english.php'));
        return $result;
    }

    /**
     * _GetFilenames
     *
     * Liefert die Dateinamensmaske.
     *
     * @param string $module Das Modul
     * @return array Die Namen
     * @author Hinrich Donner
     * @since 5.5.1
     * @version 0.1
     */
    function _GetFilenames($module = '')
    {
    	if (empty($module))
            $filelist = $this->_MakeFilenames(VKP_LANGUAGE_DIR . '/%s');
        elseif ($module == 'admin')        
            $filelist = $this->_MakeFilenames('admin/' . VKP_LANGUAGE_DIR . '%s');
        else
        {
            $modules =& vkpModules::GetInstance();
            $filelist = $this->_MakeFilenames($modules->GetFilename(VKP_LANGUAGE_DIR) . '/%s');
        }
        return $filelist;
    }
    
    /**
     * Load
     *
     * Ld die aktuelle Sprache fr ein Modul.  Wird kein Modul angegeben,
     * so wird die Sprache fr das System geladen.  Existiert die Sprache
     * nicht, und handelt es sich bei der Sprache NICHT um die Vorgabesprache,
     * dann wird die Vorgabesprache geladen.  Ist diese ebenfalls nicht 
     * verfgbar, so wird versucht die Sprache 'english' zu laden.  Ist die
     * auch nicht vorhanden, wird das Skript beendet.
     *
     * @param string $module Der Name des Moduls
     * @author Hinrich Donner
     * @since 5.5.1
     * @version 0.1
     */
    function Load($module = '')
    {
        // Dateiliste aufbereiten
        //
        $filenames = $this->_GetFilenames($module);
        
        // Versuchen die Datei zu laden
        //
        foreach ($filenames as $filename)
        {
            if (!file_exists($filename))
                continue;
            
            // Gefunden, also laden
            //
            require_once $filename;
            return true;
        }
        
        // Wenn wir hier sind, dann ist die Datei nicht vorhanden.
        //
        die("Language files are missing for {$this->current}, {$this->default} and english.");
    }
    
    /**
     * Exists
     *
     * Diese Methode prft, ob fr das gewnschte Modul eine Sprache
     * vorhanden ist.
     *
     * @param string $language Die Sprache
     * @param string $module Das Modul
     * @return bool TRUE oder FALSE
     * @author Hinrich Donner
     * @since 5.5.1
     * @version 0.1
     */
    function Exists($language, $module = '')
    {
    	if (empty($module))
            $filename = sprintf(VKP_LANGUAGE_DIR . '/lang-%s.php',
                                $language);
        elseif ($module == 'admin')
            $filename = sprintf('admin/' . VKP_LANGUAGE_DIR . '/lang-%s.php',
                                $language);
        else
        {
            $modules =& vkpModules::GetInstance();
            $filename = sprintf($modules->GetFilename(VKP_LANGUAGE_DIR) . '/lang-%s.php',
                                $language);
        }
        return file_exists($filename);
    }
    
    
} // Class

// $Log: vkplanguages.php,v $
// Revision 1.1  2004/01/02 20:39:37  hdonner
// - Sprachsteuerung ueberarbeitet
//
//
?>