<?php
// ----------------------------------------------------------------------
// File: $Id: vkprecordset.php,v 1.1.2.1 2004/01/17 22:37:58 hdonner Exp $
// ----------------------------------------------------------------------
// PHP-Nuke-VKP
// Copyright 2001-2004 by PHP-Nuke-VKP-Team
// http://developer.berlios.de/projects/phpnukevkp/
// ----------------------------------------------------------------------
// LICENSE
//
// Dieses Programm ist freie Software; Sie knnen sie beliebig verteilen
// und/oder nderungen vornehmen, solange Sie dieses unter den
// Lizenzbedingungen der Version 2 oder hher der GNU General Public
// License (GPL), verffentlicht von der Free Software Foundation tun.
//
// Dieses Programm wurde in der Hoffnung erstellt, dass es fr Sie
// ntzlich sein knnte. Es wird jedoch ohne jeden Anspruch auf
// Gewhrleistung verffentlicht. Sie knnen auch nicht davon ausgehen,
// dass das Programm Dinge verrichtet, wie es erwartet wird.
//
// Lesen Sie die Lizenzbedinguneg unter der URL
// http://www.gnu.org/copyleft/gpl.html fr weitere Details.
// ----------------------------------------------------------------------

/**
 * vkprecordset.php
 *
 * Diese Datei enthlt Klassen und Funktionen zur Handhabung
 * von DB-Records.
 *
 * @author Hinrich Donner
 * @version 5.5.1
 * @since 0.1
 * @package PHP-Nuke-VKP
 * @subpackage System
 * @category Datenbank
 * @link http://developer.berlios.de/projects/phpnukevkp/
 */

/**
 * vkpRecordSet
 *
 * Eine Klasse als Basis fr einzelne Records.
 *
 * @abstract
 * @author Hinrich Donner
 * @version 0.1
 * @since 5.5.1
 */
class vkpRecordSet
{
    /**
     * _changed
     *
     * Dieses Array enthlt die genderten Einstellungen, die mittels der Methode
     * Save gesichert werden.
     *
     * @var array
     * @access protected
     */
    var $_changed = array();

    /**
     * _config
     *
     * Diese Eigenschaft enthlt eine Referenz zur Konfiguration.
     *
     * @var vkpConfig
     * @access protected
     */
    var $_config;

    /**
     * id
     *
     * Diese Eigenschaft enthlt die ID eines Datensatzes.  blicherweise hat jeder
     * Datensatz eine eineindeutige ID, die durch den SQL-Server automatisch vergeben
     * wird (in manchen Fllen kmmert sich ADOdb um diesen Vorgang).  Diese
     * Eigenschaft sollte lediglich lesend verwendet werden. Gltige Werte sind:
     * -1, 1..MAXINT
     *
     * @var int
     * @access public
     * @see vkpRecordSet::GetId(), vkpRecordSet::SetId()
     */
    var $id = -1;

    /**
     * modified
     *
     * Wenn alle schreibenden Zugriffe auf die Eigenschaften ber die entsprechenden
     * Methoden erfolgt sind, dann ist diese Eigenschaft TRUE, sobald sich ein Wert
     * gendert hat.  Diese Eigenschaft darf nicht beschrieben werden.
     *
     * @var bool
     * @access public
     */
    var $modified = false;

    /**
     * vkpRecordSet
     *
     * Der Konstruktor.
     *
     * @author Hinrich Donner
     * @version 0.1
     * @since 5.5.1
     */
    function vkpRecordSet()
    {
        $this->_config      =& vkpConfig::GetInstance();
    }

    /**
     * _PrepForStore
     *
     * Bereitet eine Variable fr die Verwendung in einer SQL-Anweisung auf.
     *
     * @param string $name Der Name der Eigenschaft
     * @return mixed Das aufbereitete Ergebnis
     * @access protected
     * @author Hinrich Donner
     * @version 0.1
     * @since 5.5.1
     */
    function _PrepForStore($name)
    {
        $result = $this->GetProperty($name);

        // Prepare var
        //
        if (!get_magic_quotes_runtime())
            $result = addslashes($result);

        return $result;
    }

    /**
     * ExistsProperty
     *
     * Prft, ob eine angegeben Eigenschaft initialisiert ist, also existent.  Die
     * Arbeitsweise setzt zwingend voraus, dass abgeleitete Klassen ihre Eigenschaften
     * vollstndig initialisieren.
     *
     * @param string $name Der Name der Eigenschaft
     * @return bool
     * @author Hinrich Donner
     * @version 0.1
     * @since 5.5.1
     * @see vkpRecordSet::GetProperty(), vkpRecordSet::SetProperty()
     */
    function ExistsProperty($name)
    {
        if (!empty($name) && isset($this->$name))
            return true;
        return false;
    }

    /**
     * GetProperty
     *
     * Liefert den Wert einer Eigenschaft zurck. Sollte die Eigenschaft nicht existieren,
     * so wird ein Vorgabewert zurckgegeben.
     *
     * @param string $name Der Name der Eigenschaft
     * @param mixed $default Der Vorgabewert
     * @return mixed
     * @author Hinrich Donner
     * @version 0.1
     * @since 5.5.1
     * @see vkpRecordSet::ExistsProperty(), vkpRecordSet::SetProperty()
     */
    function GetProperty($name, $default = null)
    {
        if ($this->ExistsProperty(&$name))
            return $this->$name;
        return $default;
    }

    /**
     * SetProperty
     *
     * Setzt einen neuen Wert einer Eigenschaft.
     *
     * @param string $name Der Name der Eigenschaft
     * @param mixed $value Der Wert
     * @return bool
     * @author Hinrich Donner
     * @version 0.1
     * @since 5.5.1
     * @see vkpRecordSet::GetProperty(), vkpRecordSet::ExistsProperty()
     */
    function SetProperty($name, $value)
    {
        if (empty($name))
            return false;

        $this->_changed[$name] = $this->$name = $value;
        $this->modified = true;
        return true;
    }

    /**
     * GetId
     *
     * Liefert die ID des Datensatzes zurck.  Ein Wert von -1 bedeutet, dass der
     * Datensatz noch nicht in der Datenbank gespeichert ist;  0 ist kein gltiger
     * Wert.
     *
     * @return int -1, 1..MAXINT
     * @author Hinrich Donner
     * @version 0.1
     * @since 5.5.1
     * @see vkpRecordSet::SetId()
     */
    function GetId()
    {
        return $this->GetProperty('id', -1);
    }

    /**
     * SetId
     *
     * Setzt den Wert der ID.  Im Normalfall wird diese Methode nicht bentigt, da
     * beim Speichern automatisch eine ID vergeben wird.  Diese Methode ist nur beim
     * Kopieren von Daten sinnvoll.  Ein Wert von -1 veranlasst das Objekt, die Daten
     * als neuen Datensatz zu speichern, ein Wert von 0 ist ungltig und wird als -1
     * interpretiert.
     *
     * @param int $id -1, 1..MAXINT
     * @return bool
     * @author Hinrich Donner
     * @version 0.1
     * @since 5.5.1
     * @see vkpRecordSet::GetId()
     */
    function SetId($id = -1)
    {
        $_current_id = $this->GetProperty('id');
        if ($_current_id === $id)
            return true;
        $_id = (((int) $id == 0) ? -1 : $id);
        $result = $this->SetProperty('id', $_id);
        return $result;
    }
}

// $Log: vkprecordset.php,v $
// Revision 1.1.2.1  2004/01/17 22:37:58  hdonner
// - Klasse vkpRecordSet (Abstrakt)
//
//
?>
