<?php
// ----------------------------------------------------------------------
// File: $Id: vkpthemes.php,v 1.1 2004/01/02 17:12:50 hdonner Exp $
// ----------------------------------------------------------------------
// PHP-Nuke-VKP
// Copyright 2001-2004 by PHP-Nuke-VKP-Team
// http://developer.berlios.de/projects/phpnukevkp/
// ----------------------------------------------------------------------
// LICENSE
//
// Dieses Programm ist freie Software; Sie knnen sie beliebig verteilen
// und/oder nderungen vornehmen, solange Sie dieses unter den
// Lizenzbedingungen der Version 2 oder hher der GNU General Public
// License (GPL), verffentlicht von der Free Software Foundation tun.
//
// Dieses Programm wurde in der Hoffnung erstellt, dass es fr Sie
// ntzlich sein knnte. Es wird jedoch ohne jeden Anspruch auf
// Gewhrleistung verffentlicht. Sie knnen auch nicht davon ausgehen,
// dass das Programm Dinge verrichtet, wie es erwartet wird.
//
// Lesen Sie die Lizenzbedinguneg unter der URL
// http://www.gnu.org/copyleft/gpl.html fr weitere Details.
// ----------------------------------------------------------------------

/**
 * vkpthtmes.php
 *
 * Diese Datei enthlt die Klasse vkpThemes
 * 
 * @author Hinrich Donner
 * @version 5.5.1
 * @since 0.1
 * @package PHP-Nuke-VKP
 * @subpackage System
 * @category Anzeige
 * @link http://developer.berlios.de/projects/phpnukevkp/
 */

/**
 * Bentigte Klassen
 *
 * @ignore
 */
require_once VKP_INCLUDE_DIR . '/classes/vkparray.php';
require_once VKP_INCLUDE_DIR . '/classes/vkpfile.php';

/**
 * __VKP_THEMES_INSTANCE
 * 
 * Der Name der globalen Variablen, die die Instanz enthlt.
 * 
 * @access private
 * @see vkpThemes
 */
define('__VKP_THEMES_INSTANCE', '__vkp_themes_instance');

/** 
 * vkpThemes
 * 
 * Eine Klasse zur Verwaltung der Themes.
 *
 * @author Hinrich Donner
 * @version 0.1
 * @since 5.5.1
 */
class vkpThemes extends vkpArray
{
    /**
     * default 
     *        
     * Der Name des Default-Themes.
     * 
     * @var string
     */
    var $default;
    
    /**
     * vkpThemes
     *
     * Der Konstruktor.
     *
     * @author Hinrich Donner
     * @since 5.5.1
     * @version 0.1
     * @access protected
     * @see vkpThemes::GetInstance()
     */
    function vkpThemes()
    {
        $this->vkpArray();
        $this->Read();
        
        // Benutzerspezifisches Theme als Default einstellen
        //
        $config =& vkpConfig::GetInstance();
        $user   =& vkpUser::GetInstance();
        if ($config->user_theme_can_change
                && $this->IsValid($user->GetTheme()))
            $this->default = $user->GetTheme();
        else
            // Default Theme eintragen und prfen.
            //
            $this->default = $config->Default_Theme;

        if (!$this->IsValid($this->default))
            die("Invalid Theme '{$this->default}' in your config.php!");
    }
    
    /**
     * GetInstance
     *
     * Gibt die Instanz zurck
     *
     * @return vkpThemes
     * @author Hinrich Donner
     * @since 5.5.1
     * @version 0.1
     */
    function &GetInstance()
    {
    	if (!array_key_exists(__VKP_THEMES_INSTANCE, $GLOBALS)
                || !is_a($GLOBALS[__VKP_THEMES_INSTANCE], 'vkpThemes'))
            $GLOBALS[__VKP_THEMES_INSTANCE] =& new vkpThemes();
        return $GLOBALS[__VKP_THEMES_INSTANCE];
    }
    
    /**
     * Read
     *
     * Liest das Verzeichnis ein, in dem sich die Themes befinden
     * und legt eine Liste mit allen gltigen Themes an.
     *
     * @return bool Status
     * @author Hinrich Donner
     * @since 5.5.1
     * @version 0.1
     */
    function Read()
    {
        // Verzeichnisoptionen festlegen
        //
    	$dir =& new vkpDirectory(VKP_THEMES_DIR);
        $dir->ignore                = array('.',
                                            '..',
                                            'CVS');
        $dir->ignore_directories    = false;
        $dir->ignore_files          = true;      
        
        // Verzeichnis einlesen
        //
        if (false === $dir->Read())
            return false;               
        $this->Init($dir); 
        
        // Ungltige Themes entfernen
        //
        for ($i = 0; $i < $this->Count(); $i++)
        {
            if (file_exists(VKP_THEMES_DIR . '/' . $this->items[$i] . '/theme.php'))
                continue;
            unset($this->items[$i]);
        }
        sort($this->items);
        return true;
    }
    
    /**
     * IsValid
     *
     * Prft, ob das angegebene Theme gltig ist.
     *
     * @param string $themename Der Name des Themes
     * @return bool
     * @author Hinrich Donner
     * @since 5.5.1
     * @version 0.1
     */
    function IsValid($themename)
    {
        if (empty($themename))
            return false;
    	return in_array($themename, $this->GetAllAsReference());
    }
    
    /**
     * Load
     *
     * Ld das angegebene Theme. Im Normalfall sollte diese Methode
     * ohne Argumente aufgerufen werden. in diesem Fall wird das 
     * Default-Theme verwendet. In Spezialfllen kann man diese
     * Funktionalitt auch durch das Argument bersteuern.
     *
     * @param string $theme_overload
     * @author Hinrich Donner
     * @since 5.5.1
     * @version 0.1
     */
    function Load($theme_overload = '')
    {
        if (!empty($theme_overload) && $this->IsValid($theme_overload))
            $this->default = $theme_overload;

        $filename = realpath(VKP_THEMES_DIR . '/' . $this->default . '/theme.php');
        require_once $filename;
        require_once VKP_INCLUDE_DIR . '/theme-extension.php';

        // Theme-Variablen in den globalen Scope schieben.  Das betrifft im
        // wesentlichen die Farbdefinitionen.
        //
        unset($filename);
        foreach (get_defined_vars() as $name => $value)
            $GLOBALS[$name] = $value;
    }    
    
} // Class

// $Log: vkpthemes.php,v $
// Revision 1.1  2004/01/02 17:12:50  hdonner
// - OOP-API Themes
//
//
?>