<?php
// ----------------------------------------------------------------------
// File: $Id: sql_layer.php,v 1.11 2004/01/02 17:11:22 hdonner Exp $
// ----------------------------------------------------------------------
// PHP-Nuke-VKP
// Copyright 2001-2004 by PHP-Nuke-VKP-Team
// http://developer.berlios.de/projects/phpnukevkp/
// ----------------------------------------------------------------------
// LICENSE
//
// Dieses Programm ist freie Software; Sie knnen sie beliebig verteilen
// und/oder nderungen vornehmen, solange Sie dieses unter den
// Lizenzbedingungen der Version 2 oder hher der GNU General Public
// License (GPL), verffentlicht von der Free Software Foundation tun.
//
// Dieses Programm wurde in der Hoffnung erstellt, dass es fr Sie
// ntzlich sein knnte. Es wird jedoch ohne jeden Anspruch auf
// Gewhrleistung verffentlicht. Sie knnen auch nicht davon ausgehen,
// dass das Programm Dinge verrichtet, wie es erwartet wird.
//
// Lesen Sie die Lizenzbedinguneg unter der URL
// http://www.gnu.org/copyleft/gpl.html fr weitere Details.
// ----------------------------------------------------------------------

/**
 * sql_layer.php
 *
 * Diese Datei enthlt die Funktionen fr den Zugriff auf den SQL-Server.
 *
 * @author Hinrich Donner
 * @author F. Bruzi
 * @version 0.2
 * @since 5.5.1
 * @package PHP-Nuke-VKP
 * @subpackage System
 * @category Datenmanagement
 * @link http://developer.berlios.de/projects/phpnukevkp/
 */

/**
 * ADOdb Directoy
 *
 * In normalen Fllen ist dieses Verzeichnis unterhalb von includes/. Wenn aber
 * auf einem Server mehrere Installationen von PHP-Nuke VKP vorhanden sind,
 * knnen alle gemeinsam auf eine ADOdb-Installation zugreifen. Dabei muss
 * save_mode und open_base_dir beachtet werden.
 */
define('VKP_ADODB_DIR', VKP_INCLUDE_DIR . '/adodb');

/**
 * vkpSqlStatisticsInit
 *
 * Vorbereiten der internen Statistiken.
 *
 * @author Hinrich Donner
 * @since 5.5.1
 * @version 0.1
 */
function vkpSqlStatisticsInit()
{
    global $__sql_queries;

    // Anzahl der Queies auf 0 setzen und Array initialisieren
    //
    $__sql_queries      = array();
}

/**
 * vkpSqlStatisticsAdd
 *
 * Hngt eine neue Anweisung an das Array an.
 *
 * @param string $query Die Anweisung
 */
function vkpSqlStatisticsAdd($query)
{
    global $__sql_queries;
    $__sql_queries[] = $query;
}

/**
 * _vkpSqlFixType
 *
 * Passt den original Server-Type von PHP-Nuke an ADOdb an.
 *
 * @param string $type Der PHP-Nuke-Type
 * @return string Der ADOdb-Type
 * @access private
 * @since 5.5.1
 * @version 0.1
 * @author Hinrich Donner
 */
function _vkpSqlFixType($type)
{
    switch ($type)
    {
        case "MySQL":
        case "mSQL":
        case "ODBC":
        case "Sybase":
            // Nur Kleinschreibung erforderlich
            //
            $result = strtolower($type);
            break;

        case "Interbase":
            // Sehr schwierige Entscheidung. Interbase existiert so nicht
            // mehr. Es gibt da Borland Interbase und das Open Source
            // Projekt FireBird. Beide sind aber lediglich im Beta-Status.
            // Deshalb nehmen wir 'ibase' fr Interbase bis Version 6.0
            //
            $result = 'ibase';
            break;

        case "PostgreSQL":
        case "PostgreSQL_local":
            // 'local' entfernen, da unntig.  Kein break am Ende!
            //
            $result = "postgresql";
            break;

        case "ODBC_Adabas":
            // Sollte vom Standard-Treiber abgedeckt sein
            //
            $result = 'odbc';
            break;

        default:
            $result = $type;
            break;
    }
    return $result;
}

/**
 * vkpSqlServerInfo
 *
 * Liefert Informationen zum SQL-Server.  Der Rckgabewert ist ein
 * Array mit zwei Elementen: 'description' enthlt eine Beschreibung
 * und 'version' enthlt Informationen zur Version.
 *
 * @return array
 */
function vkpSqlServerInfo()
{
    $db     =& vkpSqlGetConn();
    $result = $db->ServerInfo();
    return $result;
}

/**
 * sql_connect
 *
 * Stellt die Verbindung zum Datenbank-Server her.
 *
 * @param string $host Der Name des Servers oder die IP-Adresse
 * @param string $user Der Benutzer, der auf die Datenbank zugreifen darf
 * @param string $password Das dazugehrige Kennwort
 * @param string $db Der Name der Datenbank
 * @return resource Die Resource fr den Zugriff oder FALSE
 */
function &sql_connect($host, $user, $password, $db)
{
    global $currentlang;

    // ADOdb Layer laden
    //
    require_once VKP_ADODB_DIR . '/adodb.inc.php';

    global $ADODB_ASSOC_CASE, $ADODB_FETCH_MODE, $ADODB_LANG;
    switch ($currentlang)
    {
        case 'german':
            $ADODB_LANG = 'de';
            break;

        default:
            $ADODB_LANG = 'en';
    }
    // Assoc
    //
    $ADODB_FETCH_MODE = 3;      // Assoc. und numerisch
    $ADODB_ASSOC_CASE = 2;      // Native

    // Statistiken vorbereiten
    //
    vkpSqlStatisticsInit();

    // Typ anpassen
    //
    $config =& vkpConfig::GetInstance();
    $_dbtype = _vkpSqlFixType($config->dbtype);

    // Verbindung herstellen
    //
    $_dbtype = strtolower($_dbtype);
    $GLOBALS['__dbconn'] =& AdoNewConnection($_dbtype);

    global $__dbconn;

    if (false === $__dbconn->Connect($host, $user, $password, $db))
        die(__DB_CANNOT_CONNECT);

    // Unsauber, aber notwendig ist die Bereitsstellung der tatschlichen
    // DB-Resource
    //
    $dbi = $__dbconn->_connectionID;

    return $dbi;
}

/**
 * sql_logout
 *
 * Vom Datenbank-Server abmelden.  Diese Funktion ist sinnlos.
 */
function sql_logout()
{
}

/**
 * vkpSqlCleanQuery
 *
 * Testet die vorgegebene SQL-Anweisung auf einen mglichen Angriff.
 * Um einen Angriff durchfhren zu knnen, muss der Angreifer eine
 * weitere SQL-Anweisung in die bestehende einschleusen.  Somit wren
 * mindestens zwei SQL-Anweisungen in einem String, die durch ein
 * Semikolon voneinander getrennt sind.  Ist ein solches Semikolon
 * vorhanden, und befindet es sich nicht innerhalb eines Strings und
 * ist nicht mit dem Escape-Zeichen unwirksam gemacht, wird ab dem
 * Semikolon alles entfernt. In den meisten Fllen wird das zu einer
 * fehlerhaften Anweisung fhren, was an diesem Punkt aber egal sein
 * drfte.
 *
 * @param string $query Die SQL-Anweisung
 * @return string
 * @version 0.1
 * @since 5.5.1
 */
function vkpSqlCleanQuery($query)
{
    // Fhrende und schlieende White Spaces entfernen
    //
    $result = trim($query);

    // Wenn kein Semikolon vorkommt, dann kann kein Inject
    // vorliegen.
    //
    if (!strpos($result, ';'))
        return $result;

    $length = strlen($result);
    $in_backticks       = false;
    $in_quotes          = false;
    $in_doublequotes    = false;
    $escape             = false;

    for ($i = 0; $i < $length; $i++)
    {
        switch ($query[$i])
        {
            case '\\':
                $escape = !$escape;
                break;

            case '\'':
                if (!$escape)
                    $in_quotes = !$in_quotes;
                break;

            case '"':
                if (!$escape)
                    $in_doublequotes = !$in_doublequotes;
                break;

            case '`':
                if (!$escape)
                    $in_backticks = !$in_backticks;
                break;

            case ';':   // Semikolon
                if (!($escape || $in_quotes || $in_doublequotes))
                {
                    // Mgliche Injection! Rest lschen und vollstndiger
                    // Abbruch
                    //
                    $result = substr($result, 0, $i);
                    return $result;
                }
                break;

            default:
                $escape = false;
                break;
        }
    }
    return $result;
}

/**
 * vkpSqlGetConn
 *
 * Liefert eine Referenz zu dem ADOdb-Objekt.
 *
 * @return ADOConnection Die Referenz
 */
function &vkpSqlGetConn()
{
    return $GLOBALS['__dbconn'];
}

/**
 * sql_query
 *
 * Fhrt eine SQL-Anweisung aus.
 *
 * @param string $query Die Anweisung
 * @return ADORecordSet Das Ergebnis als Resource oder TRUE|FALSE
 */
function &sql_query($query)
{
    // SQL prfen und subern
    //
    $query = vkpSqlCleanQuery($query);

    // SQL-Statistik erweitern
    //
    vkpSqlStatisticsAdd($query);

    // DB-Connector holen
    //
    $db = vkpSqlGetConn();

    // LIMIT-Anweisung entfernen, da einige Server damit nicht umgehen
    // knnen. ADOdb hat dafr aber Lsungen...
    //
    if (preg_match("/LIMIT[\s]+([0-9]+)([\s]*,[\s]*([0-9]+)[\s]*)*$/i", $query, $res))
    {
        // Indizies 0, 1 und 3 sind relevant.
        //
        $query = substr($query, 0, strpos($query, $res[0]));
        if (isset($res[3]))
            $dbr = $db->SelectLimit($query, $res[3], $res[1]);
        else
            $dbr = $db->SelectLimit($query, $res[1]);
    }
    else
        $dbr = $db->Execute($query);

    return $dbr;
}

/**
 * sql_num_rows
 *
 * Liefert die Zahl der Datenstze der letzten Anweisung (SELECT)
 *
 * @param ADORecordSet $res Die Datenbank-Resource
 */
function sql_num_rows(&$res)
{
    $result = $res->RecordCount();
    return $result;
}

/**
 * sql_fetch_row
 *
 * Gibt einen Datensatz zurck
 *
 * @param ADORecordSet $res Datenbank-Resource
 * @return array Der Datensatz
 */
function sql_fetch_row(&$res)
{
    $result = $res->FetchRow();
    return $result;
}

/**
 * sql_fetch_array
 *
 * Liefert einen Datensatz
 *
 * @param ADORecordSet $res Datenbank-Resource
 * @return array Der Datensatz
 */
function sql_fetch_array(&$res)
{
    $result = $res->FetchRow();
    return $result;
}

/**
 * sql_fetch_object
 *
 * Dasselbe in Grn, aber den Datensatz als Objekt
 *
 * @param ADORecordSet $res Datenbank-Resource
 * @param bool $toupper Wenn TRUE, dann werden die Feldnamen in Groschrift konvertiert
 * @return object
 */
function sql_fetch_object(&$res, $toupper = false)
{
    $result = $res->FetchNextObject($toupper);
    return $result;
}

/**
 * sql_free_result
 *
 * Speicher aufrumen.
 *
 * @param ADORecordSet $res Datenbank-Resource
 */
function sql_free_result(&$res)
{
    $res->Close();
}

/**
 * vkpSqlRowCount
 *
 * Liefert die Anzahl der Datenstze zurck.
 *
 * @param string $table Der Name der Tabelle
 * @param string $where Eine WHERE-Anweisung
 * @return int Die Anzahl
 */
function vkpSqlRowCount($table, $where = '')
{
    if (empty($table))
        return 0;

    if (empty($where))
        $sql = "SELECT COUNT(*) AS `records` FROM `$table`";
    else
        $sql = "SELECT COUNT(*) AS `records` FROM `$table` WHERE ($where)";

    vkpSqlStatisticsAdd($sql);

    $db =& vkpSqlGetConn();
    if (false === ($dbr = $db->Execute($sql)))
        return 0;

    $result = $dbr->Fields('records');
    $dbr->Close();
    return $result;
}

// $Log: sql_layer.php,v $
// Revision 1.11  2004/01/02 17:11:22  hdonner
// - Weniger globale Variablen
//
// Revision 1.10  2003/11/23 16:34:34  hdonner
// - vkpSqlRowCount(), da immer wieder benoetigt
//
// Revision 1.9  2003/11/23 13:46:49  hdonner
// - Klasse ResultSet entfernt
//
// Revision 1.8  2003/11/23 11:58:46  hdonner
// - sql_layer auf ADOdb umgestellt.
//
// Revision 1.7  2003/11/22 10:25:26  hdonner
// - ADOdb-Integration vorbereitet
//
// Revision 1.6  2003/11/12 19:15:47  hdonner
// - PHP_SELF entfernt
//
// Revision 1.5  2003/11/10 08:26:36  hdonner
// - Genereller Schutz vor SQL-Injections in sql_query()
//
// Revision 1.4  2003/11/09 15:23:22  hdonner
// - Der Versuch einer Formatierung und Dokumentation
//
// Revision 1.3  2003/11/09 14:41:48  hdonner
// - Ausgabe aller Statements bei $sql_debug=1
//
//
?>
